Index: snapshot/module_snapshot.h |
diff --git a/snapshot/module_snapshot.h b/snapshot/module_snapshot.h |
index d8f1ae6bd92f81a00b54dde1d2707eb228ee5564..6c397ed0a71e6210f988807d8ffea5e9b14ff340 100644 |
--- a/snapshot/module_snapshot.h |
+++ b/snapshot/module_snapshot.h |
@@ -109,11 +109,16 @@ class ModuleSnapshot { |
//! \brief Returns the module’s type. |
virtual ModuleType GetModuleType() const = 0; |
//! \brief Returns the module’s UUID in the \a uuid parameter. |
//! |
//! A snapshot module’s UUID is taken directly from the module itself. If the |
//! module does not have a UUID, the \a uuid parameter will be zeroed out. |
- virtual void UUID(crashpad::UUID* uuid) const = 0; |
+ //! |
+ //! \a age is the number of times the UUID has been reused. This occurs on |
+ //! Windows with incremental linking. On other platforms \a age will always be |
+ //! `0`. |
+ virtual void UUIDAndAge(crashpad::UUID* uuid, uint32_t* age) const = 0; |
//! \brief Returns string annotations recorded in the module. |
//! |
@@ -109,11 +109,16 @@ class ModuleSnapshot { |
//! \brief Returns the module’s type. |
virtual ModuleType GetModuleType() const = 0; |
- //! \brief Returns the module’s UUID in the \a uuid parameter. |
+ //! \brief Returns the module’s UUID in the \a uuid parameter, and the age of |
+ //! that UUID in \a age. |
//! |
//! A snapshot module’s UUID is taken directly from the module itself. If the |